pub struct IvfPqCodebook {
pub coarse_centroids: Vec<Vec<f32>>,
pub pq: PQCodebook,
pub nlist: usize,
pub nprobe: usize,
pub pq_m: usize,
pub dim: usize,
pub metric: VectorMetric,
pub residual: bool,
}Expand description
Shared codebook trained once and reused across all shards. When multiple shards share the same codebook, their ADC distances are numerically comparable — cross-shard merge is correct without reranking.
Fields
coarse_centroids: Vec<Vec<f32>>pq: PQCodebooknlist: usizenprobe: usizepq_m: usizedim: usizemetric: VectorMetricresidual: boolTrait Implementations
Sourceimpl Clone for IvfPqCodebook
impl Clone for IvfPqCodebook
Sourcefn clone(&self) -> IvfPqCodebook
fn clone(&self) -> IvfPqCodebook
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for IvfPqCodebook
impl RefUnwindSafe for IvfPqCodebook
impl Send for IvfPqCodebook
impl Sync for IvfPqCodebook
impl Unpin for IvfPqCodebook
impl UnsafeUnpin for IvfPqCodebook
impl UnwindSafe for IvfPqCodebook